# -*- coding: utf-8 -*-
from setuphelpers import *


def install():
    if windows_version() < Version("8.1", 2):
        was_smb1server = registry_readstring(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Services\LanmanServer\Parameters", "SMB1", 1)
        if was_smb1server:
            print("Disable SMB1 server service")
            registry_setstring(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Services\LanmanServer\Parameters", "SMB1", 0, type=REG_DWORD)
        else:
            print("OK: SMB1 server disabled in registry")
    else:
        was_smb1server = run_powershell("Get-SmbServerConfiguration | Select EnableSMB1Protocol").get("EnableSMB1Protocol", True)
        print("Current SMB1 status : %s" % (was_smb1server))
        if was_smb1server:
            print("Disabling SMB1")
            run_powershell("Set-SmbServerConfiguration -EnableSMB1Protocol $false -Force")
            run_powershell("Disable-WindowsOptionalFeature -Online -FeatureName smb1protocol -NoRestart")

    # before Vista, no SMB2, so check patch
    if windows_version() < Version("6.0"):
        # check if KB4012598 is installed
        if not is_kb_installed("KB4012598"):
            install_kb4012598()

    if was_smb1server:
        restart_smb_service()
    else:
        print("No reboot required")


def uninstall():
    if windows_version() < Version("8.1"):
        was_smb1server = registry_readstring(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Services\LanmanServer\Parameters", "SMB1", 0)
        registry_setstring(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Services\LanmanServer\Parameters", "SMB1", 1, type=REG_DWORD)
        if not was_smb1server:
            restart_smb_service()
        else:
            print("OK: SMB1 server enabled in registry")
    else:
        was_smb1server = run_powershell("Get-SmbServerConfiguration | Select EnableSMB1Protocol").get("EnableSMB1Protocol", True)
        print("Current SMB1 status : %s" % (was_smb1server))
        if not was_smb1server:
            print("Enabling SMB1")
            run_powershell("Set-SmbServerConfiguration -EnableSMB1Protocol $true -Force")
            run_powershell("Enable-WindowsOptionalFeature -Online -FeatureName smb1protocol -NoRestart")

    if not was_smb1server:
        restart_smb_service()
    else:
        print("No reboot required")


def restart_smb_service():
    run_powershell("Restart-Service -Name LanmanServer -Force")
    run_powershell("Restart-Service -Name LanmanWorkstation -Force")


def install_kb4012598():
    error("Please install kb4012598")
